==> Lingua-StopWords-0.05.tar.gz: Lingua-StopWords-0.05/lib/Lingua/StopWords/ES.pm <==
package Lingua::StopWords::ES;

use strict;
use warnings;

use Exporter;
our @ISA = qw(Exporter);

our %EXPORT_TAGS = ( 'all' => [ qw( getStopWords ) ] ); 
our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
our $VERSION = 0.05;

sub getStopWords {
    if ( @_ and $_[0] eq 'UTF-8' ) {
        # adding U0 causes the result to be flagged as UTF-8
        my %stoplist = map { ( pack("U0a*", $_), 1 ) } qw( 
            de la que el en y a los del se las por un para con no una su al
            lo como más pero sus le ya o este sí porque esta entre cuando
            muy sin sobre también me hasta hay donde quien desde todo nos
            durante todos uno les ni contra otros ese eso ante ellos e esto
            mí antes algunos qué unos yo otro otras otra él tanto esa
            estos mucho quienes nada muchos cual poco ella estar estas
            algunas algo nosotros mi mis tú te ti tu tus ellas nosotras
            vosostros vosostras os mío mía míos mías tuyo tuya tuyos
            tuyas suyo suya suyos suyas nuestro nuestra nuestros nuestras
            vuestro vuestra vuestros vuestras esos esas estoy estás está
            estamos estáis están esté estés estemos estéis estén
            estaré estarás estará estaremos estaréis estarán estaría
            estarías estaríamos estaríais estarían estaba estabas
            estábamos estabais estaban estuve estuviste estuvo estuvimos
            estuvisteis estuvieron estuviera estuvieras estuviéramos
            estuvierais estuvieran estuviese estuvieses estuviésemos
            estuvieseis estuviesen estando estado estada estados estadas
            estad he has ha hemos habéis han haya hayas hayamos hayáis
            hayan habré habrás habrá habremos habréis habrán habría
            habrías habríamos habríais habrían había habías habíamos
            habíais habían hube hubiste hubo hubimos hubisteis hubieron
            hubiera hubieras hubiéramos hubierais hubieran hubiese
            hubieses hubiésemos hubieseis hubiesen habiendo habido habida
            habidos habidas soy eres es somos sois son sea seas seamos
            seáis sean seré serás será seremos seréis serán sería
            serías seríamos seríais serían era eras éramos erais eran
            fui fuiste fue fuimos fuisteis fueron fuera fueras fuéramos
            fuerais fueran fuese fueses fuésemos fueseis fuesen sintiendo
            sentido sentida sentidos sentidas siente sentid tengo tienes
            tiene tenemos tenéis tienen tenga tengas tengamos tengáis
            tengan tendré tendrás tendrá tendremos tendréis tendrán
            tendría tendrías tendríamos tendríais tendrían tenía
            tenías teníamos teníais tenían tuve tuviste tuvo tuvimos
            tuvisteis tuvieron tuviera tuvieras tuviéramos tuvierais
            tuvieran tuviese tuvieses tuviésemos tuvieseis tuviesen
            teniendo tenido tenida tenidos tenidas tened 
        );
        return \%stoplist;
    }
    else {
        my %stoplist = map { ( $_, 1 ) } qw( 
            de la que el en y a los del se las por un para con no una su al
            lo como ms pero sus le ya o este s porque esta entre cuando
            muy sin sobre tambin me hasta hay donde quien desde todo nos
            durante todos uno les ni contra otros ese eso ante ellos e esto
            m antes algunos qu unos yo otro otras otra l tanto esa estos
            mucho quienes nada muchos cual poco ella estar estas algunas
            algo nosotros mi mis t te ti tu tus ellas nosotras vosostros
            vosostras os mo ma mos mas tuyo tuya tuyos tuyas suyo suya
            suyos suyas nuestro nuestra nuestros nuestras vuestro vuestra
            vuestros vuestras esos esas estoy ests est estamos estis
            estn est ests estemos estis estn estar estars estar
            estaremos estaris estarn estara estaras estaramos
            estarais estaran estaba estabas estbamos estabais estaban
            estuve estuviste estuvo estuvimos estuvisteis estuvieron
            estuviera estuvieras estuviramos estuvierais estuvieran
            estuviese estuvieses estuvisemos estuvieseis estuviesen
            estando estado estada estados estadas estad he has ha hemos
            habis han haya hayas hayamos hayis hayan habr habrs habr
            habremos habris habrn habra habras habramos habrais
            habran haba habas habamos habais haban hube hubiste hubo
            hubimos hubisteis hubieron hubiera hubieras hubiramos
            hubierais hubieran hubiese hubieses hubisemos hubieseis
            hubiesen habiendo habido habida habidos habidas soy eres es
            somos sois son sea seas seamos seis sean ser sers ser
            seremos seris sern sera seras seramos serais seran era
            eras ramos erais eran fui fuiste fue fuimos fuisteis fueron
            fuera fueras furamos fuerais fueran fuese fueses fusemos
            fueseis fuesen sintiendo sentido sentida sentidos sentidas
            siente sentid tengo tienes tiene tenemos tenis tienen tenga
            tengas tengamos tengis tengan tendr tendrs tendr tendremos
            tendris tendrn tendra tendras tendramos tendrais tendran
            tena tenas tenamos tenais tenan tuve tuviste tuvo tuvimos
            tuvisteis tuvieron tuviera tuvieras tuviramos tuvierais
            tuvieran tuviese tuvieses tuvisemos tuvieseis tuviesen
            teniendo tenido tenida tenidos tenidas tened 
        );
        return \%stoplist;
    }
}

1;

==> Lingua-StopWords-0.09.tar.gz: Lingua-StopWords-0.09/lib/Lingua/StopWords/ES.pm <==
package Lingua::StopWords::ES;

use strict;
use warnings;

use Exporter;
our @ISA = qw(Exporter);

our %EXPORT_TAGS = ( 'all' => [ qw( getStopWords ) ] ); 
our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
our $VERSION = 0.08;

sub getStopWords {
    if ( @_ and $_[0] eq 'UTF-8' ) {
        # adding U0 causes the result to be flagged as UTF-8
        my %stoplist = map { ( pack("U0a*", $_), 1 ) } qw( 
            de la que el en y a los del se las por un para con no una su al
            lo como más pero sus le ya o este sí porque esta entre cuando
            muy sin sobre también me hasta hay donde quien desde todo nos
            durante todos uno les ni contra otros ese eso ante ellos e esto
            mí antes algunos qué unos yo otro otras otra él tanto esa
            estos mucho quienes nada muchos cual poco ella estar estas
            algunas algo nosotros mi mis tú te ti tu tus ellas nosotras
            vosotros vosotras os mío mía míos mías tuyo tuya tuyos
            tuyas suyo suya suyos suyas nuestro nuestra nuestros nuestras
            vuestro vuestra vuestros vuestras esos esas estoy estás está
            estamos estáis están esté estés estemos estéis estén
            estaré estarás estará estaremos estaréis estarán estaría
            estarías estaríamos estaríais estarían estaba estabas
            estábamos estabais estaban estuve estuviste estuvo estuvimos
            estuvisteis estuvieron estuviera estuvieras estuviéramos
            estuvierais estuvieran estuviese estuvieses estuviésemos
            estuvieseis estuviesen estando estado estada estados estadas
            estad he has ha hemos habéis han haya hayas hayamos hayáis
            hayan habré habrás habrá habremos habréis habrán habría
            habrías habríamos habríais habrían había habías habíamos
            habíais habían hube hubiste hubo hubimos hubisteis hubieron
            hubiera hubieras hubiéramos hubierais hubieran hubiese
            hubieses hubiésemos hubieseis hubiesen habiendo habido habida
            habidos habidas soy eres es somos sois son sea seas seamos
            seáis sean seré serás será seremos seréis serán sería
            serías seríamos seríais serían era eras éramos erais eran
            fui fuiste fue fuimos fuisteis fueron fuera fueras fuéramos
            fuerais fueran fuese fueses fuésemos fueseis fuesen siendo
            sido tengo tienes tiene tenemos tenéis tienen tenga tengas
            tengamos tengáis tengan tendré tendrás tendrá tendremos
            tendréis tendrán tendría tendrías tendríamos tendríais
            tendrían tenía tenías teníamos teníais tenían tuve
            tuviste tuvo tuvimos tuvisteis tuvieron tuviera tuvieras
            tuviéramos tuvierais tuvieran tuviese tuvieses tuviésemos
            tuvieseis tuviesen teniendo tenido tenida tenidos tenidas tened 
        );
        return \%stoplist;
    }
    else {
        my %stoplist = map { ( $_, 1 ) } qw( 
            de la que el en y a los del se las por un para con no una su al
            lo como ms pero sus le ya o este s porque esta entre cuando
            muy sin sobre tambin me hasta hay donde quien desde todo nos
            durante todos uno les ni contra otros ese eso ante ellos e esto
            m antes algunos qu unos yo otro otras otra l tanto esa estos
            mucho quienes nada muchos cual poco ella estar estas algunas
            algo nosotros mi mis t te ti tu tus ellas nosotras vosotros
            vosotras os mo ma mos mas tuyo tuya tuyos tuyas suyo suya
            suyos suyas nuestro nuestra nuestros nuestras vuestro vuestra
            vuestros vuestras esos esas estoy ests est estamos estis
            estn est ests estemos estis estn estar estars estar
            estaremos estaris estarn estara estaras estaramos
            estarais estaran estaba estabas estbamos estabais estaban
            estuve estuviste estuvo estuvimos estuvisteis estuvieron
            estuviera estuvieras estuviramos estuvierais estuvieran
            estuviese estuvieses estuvisemos estuvieseis estuviesen
            estando estado estada estados estadas estad he has ha hemos
            habis han haya hayas hayamos hayis hayan habr habrs habr
            habremos habris habrn habra habras habramos habrais
            habran haba habas habamos habais haban hube hubiste hubo
            hubimos hubisteis hubieron hubiera hubieras hubiramos
            hubierais hubieran hubiese hubieses hubisemos hubieseis
            hubiesen habiendo habido habida habidos habidas soy eres es
            somos sois son sea seas seamos seis sean ser sers ser
            seremos seris sern sera seras seramos serais seran era
            eras ramos erais eran fui fuiste fue fuimos fuisteis fueron
            fuera fueras furamos fuerais fueran fuese fueses fusemos
            fueseis fuesen siendo sido tengo tienes tiene tenemos tenis
            tienen tenga tengas tengamos tengis tengan tendr tendrs
            tendr tendremos tendris tendrn tendra tendras tendramos
            tendrais tendran tena tenas tenamos tenais tenan tuve
            tuviste tuvo tuvimos tuvisteis tuvieron tuviera tuvieras
            tuviramos tuvierais tuvieran tuviese tuvieses tuvisemos
            tuvieseis tuviesen teniendo tenido tenida tenidos tenidas tened 
        );
        return \%stoplist;
    }
}

1;
